# Tycho depends on itself, and Eclipse to build but in certain cases these
# requirements may not be satisfiable then building Tycho becomes problematic.
# For example:
# * A library (in Fedora) used by Tycho's runtime broke API and so Tycho
#   from the buildroot is broken
# * Building into a new distro or buildroot, where neither Tycho nor Eclipse
#   is available yet and we need to build Tycho before building Eclipse
# In bootstrap mode, javac and plain xmvn are used to build a subset of
# Tycho such that it can build a bootstrap mode Eclipse and subsequently
# fully rebuild itself. In this mode, there may be reduced functionality,
# so a full non-bootstrap mode build should always be done afterwards.
%bcond_without bootstrap

# Allow conditionally building without Junit 5 support
%bcond_with junit5

# Release tags or git SHAs
%global git_tag tycho-%{version}
%global fp_p2_git_tag 290f67a4c717599b2f5166ea89aa5365571314b1

%global fp_p2_version 0.0.1
%global fp_p2_snap -SNAPSHOT

# The location of the xmvn dir into which we need to install the xmvn plugin
%global xmvn_libdir %(realpath $(dirname $(readlink -f $(which xmvn)))/../lib)

%define __requires_exclude osgi*

Name:           tycho
Version:        1.7.0
Release:        %mkrel 2
Group:          Development/Java
Summary:        Plugins and extensions for building Eclipse plugins and OSGI bundles with Maven

# license file is missing but all files having some licensing information are ASL 2.0
License:        ASL 2.0 and EPL-1.0
URL:            http://eclipse.org/tycho

# Tycho project source
Source0:        http://git.eclipse.org/c/tycho/org.eclipse.tycho.git/snapshot/org.eclipse.tycho-%{git_tag}.tar.xz
# Eclipse Plugin Project supporting filesystem as p2 repository
Source1:        https://github.com/rgrunber/fedoraproject-p2/archive/%{fp_p2_git_tag}/fedoraproject-p2-%{fp_p2_git_tag}.tar.gz

# this is a workaround for maven-plugin-plugin changes that happened after
# version 2.4.3 (impossible to have empty mojo created as aggregate). This
# should be fixed upstream properly
Source2:        EmptyMojo.java
Source3:        tycho-scripts.sh
Source4:        tycho-bootstrap.sh
Source5:        tycho-debundle.sh
# Script that can be used to install or simulate installation of P2
# artifacts. It is used in OSGi requires generation.
Source6:        p2-install.sh

# Fedora Eclipse bundles needed to build Tycho when Eclipse is not present
# or when the Eclipse that is present is not compatible
%if %{with bootstrap}
Source10:       eclipse-bootstrap-2020-09.tar.xz
%endif

# Fedora-specific patches
Patch0:         0001-Fix-the-Tycho-build-to-work-on-Fedora.patch
Patch1:         0002-Implement-a-custom-resolver-for-Tycho-in-local-mode.patch
Patch2:         0003-Tycho-should-always-delegate-artifact-resolution-to-.patch
Patch6:         0007-Use-custom-resolver-for-tycho-eclipserun-plugin.patch
# Submitted upstream: https://bugs.eclipse.org/bugs/show_bug.cgi?id=537963
Patch3:         0004-Bug-537963-Make-the-default-EE-Java-1.8.patch
# Fix compile error with uncaught exception
Patch4:         0005-Fix-uncaught-exception.patch
# Fix incorrect generated requires
Patch5:         0006-Fix-dependency-problems-when-bootstrapping-with-extr.patch
# Updated polyglot
Patch7:         0008-Bug-561832-Upgrade-to-takari-polyglot-maven-Release-.patch
# Build against 4.17
Patch8:         0009-Update-to-Platform-4.17.patch

# Upstream Eclipse no longer supports non-64bit arches
ExcludeArch: s390 %{arm} %{ix86}

BuildArch:      noarch

# Extras was folded into the main tycho package in F31
Obsoletes: tycho-extras < 1.6.0-1
Provides:  tycho-extras = %{version}-%{release}

BuildRequires:  maven-local
BuildRequires:  mvn(biz.aQute.bnd:bnd-maven-plugin)
BuildRequires:  mvn(com.beust:jcommander)
BuildRequires:  mvn(de.pdark:decentxml)
BuildRequires:  mvn(io.takari.polyglot:polyglot-common) >= 0.4.5
BuildRequires:  mvn(org.apache.commons:commons-compress)
BuildRequires:  mvn(org.apache.commons:commons-exec)
BuildRequires:  mvn(org.apache.commons:commons-lang3)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven:maven-archiver)
BuildRequires:  mvn(org.apache.maven:maven-compat)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.apache.maven:maven-model-builder)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.apache.maven.plugins:maven-clean-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-dependency-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-install-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-source-plugin)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.surefire:maven-surefire-common)
BuildRequires:  mvn(org.apache.maven.surefire:surefire-api)
BuildRequires:  mvn(org.codehaus.plexus:plexus-archiver)
BuildRequires:  mvn(org.codehaus.plexus:plexus-compiler-api)
BuildRequires:  mvn(org.codehaus.plexus:plexus-compiler-manager)
BuildRequires:  mvn(org.codehaus.plexus:plexus-component-annotations)
BuildRequires:  mvn(org.codehaus.plexus:plexus-component-metadata)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildRequires:  mvn(org.eclipse.jdt:ecj)
BuildRequires:  mvn(org.eclipse.sisu:org.eclipse.sisu.plexus)
BuildRequires:  mvn(org.fedoraproject.xmvn:xmvn-api)
BuildRequires:  mvn(org.fedoraproject.xmvn:xmvn-core)
BuildRequires:  mvn(org.fedoraproject.xmvn:xmvn-install)
BuildRequires:  mvn(org.fedoraproject.xmvn:xmvn-parent:pom:)
BuildRequires:  mvn(org.ow2.asm:asm-tree)
BuildRequires:  mvn(org.ow2.asm:asm-util)
BuildRequires:  mvn(org.slf4j:slf4j-api)
BuildRequires:  mvn(org.slf4j:slf4j-simple)
%if %{with junit5}
BuildRequires:  mvn(org.apache.maven.surefire:surefire-junit-platform)
BuildRequires:  mvn(org.apiguardian:apiguardian-api)
BuildRequires:  mvn(org.opentest4j:opentest4j)
%endif

%if ! %{with bootstrap}
# Ordinarily Tycho additionally requires itself and Eclipse to build
BuildRequires:  %{name}
BuildRequires:  eclipse-platform >= 1:4.17
%else
# For bootstrapping, we just need the dependencies of the Eclipse bundles we use
BuildRequires:  osgi(com.ibm.icu)
BuildRequires:  osgi(org.apache.commons.jxpath)
BuildRequires:  osgi(org.apache.batik.css)
BuildRequires:  osgi(org.apache.felix.scr)
BuildRequires:  osgi(org.sat4j.core)
BuildRequires:  osgi(org.sat4j.pb)
BuildRequires:  osgi(org.w3c.css.sac)
BuildRequires:  glassfish-annotation-api
BuildRequires:  glassfish-servlet-api
BuildRequires:  glassfish-jsp-api
BuildRequires:  jna
BuildRequires:  jna-contrib
%endif
BuildRequires:  zip

Requires:       maven-local
Requires:       xmvn-minimal
Requires:       ecj

%if ! %{with bootstrap}
Requires:       eclipse-platform >= 1:4.17
%endif

# maven-clean-plugin is bound to "initialize" Maven phase for
# "eclipse-repository" projects
Requires:       maven-clean-plugin

%description
Tycho is a set of Maven plugins and extensions for building Eclipse
plugins and OSGI bundles with Maven. Eclipse plugins and OSGI bundles
have their own metadata for expressing dependencies, source folder
locations, etc. that are normally found in a Maven POM. Tycho uses
native metadata for Eclipse plugins and OSGi bundles and uses the POM
to configure and drive the build. Tycho supports bundles, fragments,
features, update site projects and RCP applications. Tycho also knows
how to run JUnit test plugins using OSGi runtime and there is also
support for sharing build results using Maven artifact repositories.

Tycho plugins introduce new packaging types and the corresponding
lifecycle bindings that allow Maven to use OSGi and Eclipse metadata
during a Maven build. OSGi rules are used to resolve project
dependencies and package visibility restrictions are honored by the
OSGi-aware JDT-based compiler plugin. Tycho will use OSGi metadata and
OSGi rules to calculate project dependencies dynamically and injects
them into the Maven project model at build time. Tycho supports all
attributes supported by the Eclipse OSGi resolver (Require-Bundle,
Import-Package, Eclipse-GenericRequire, etc). Tycho will use proper
classpath access rules during compilation. Tycho supports all project
types supported by PDE and will use PDE/JDT project metadata where
possible. One important design goal in Tycho is to make sure there is
no duplication of metadata between POM and OSGi metadata.

%package javadoc
Summary: Javadocs for %{name}
# Extras was folded into the main tycho package in F31
Obsoletes: tycho-extras-javadoc < 1.6.0-1
Provides:  tycho-extras-javadoc = %{version}-%{release}

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -n org.eclipse.tycho-%{git_tag} -a 1
mv fedoraproject-p2-%{fp_p2_git_tag} fedoraproject-p2

%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1

# Unneeded for RPM builds
%pom_remove_plugin :maven-site-plugin

# These tycho plug-ins don't make sense in the context of RPM builds of Eclipse plug-ins
%pom_disable_module tycho-buildtimestamp-jgit tycho-extras
%pom_disable_module tycho-sourceref-jgit tycho-extras

%if %{without junit5}
%pom_disable_module org.eclipse.tycho.surefire.junit5 tycho-surefire
%pom_disable_module org.eclipse.tycho.surefire.junit54 tycho-surefire
%pom_disable_module org.eclipse.tycho.surefire.junit55 tycho-surefire
%pom_disable_module org.eclipse.tycho.surefire.junit56 tycho-surefire
%pom_remove_dep ":org.eclipse.tycho.surefire.junit5" tycho-surefire/tycho-surefire-plugin
%pom_remove_dep ":org.eclipse.tycho.surefire.junit54" tycho-surefire/tycho-surefire-plugin
%pom_remove_dep ":org.eclipse.tycho.surefire.junit55" tycho-surefire/tycho-surefire-plugin
%pom_remove_dep ":org.eclipse.tycho.surefire.junit56" tycho-surefire/tycho-surefire-plugin
%endif

# Move from org.sonatype.aether to org.eclipse.aether
find . -name "*.java" | xargs sed -i 's/org.sonatype.aether/org.eclipse.aether/g'
find . -name "*.java" | xargs sed -i 's/org.eclipse.aether.util.DefaultRepositorySystemSession/org.eclipse.aether.DefaultRepositorySystemSession/g'
sed -i 's/public int getPriority/public float getPriority/g' tycho-core/src/main/java/org/eclipse/tycho/core/p2/P2RepositoryConnectorFactory.java

# place empty mojo in place
mkdir -p tycho-maven-plugin/src/main/java/org/fedoraproject
pushd tycho-maven-plugin/src/main/java/org/fedoraproject
cp %{SOURCE2} .
popd

# Homogenise requirement on OSGi bundle
%if %{with bootstrap}
sed -i -e "s/>org.eclipse.platform</>org.eclipse.tycho</" pom.xml tycho-core/pom.xml sisu-equinox/sisu-equinox-embedder/pom.xml
%else
sed -i -e "s/>org.eclipse.tycho</>org.eclipse.platform</" fedoraproject-p2/xmvn-p2-installer-plugin/pom.xml
%endif

# Target platform does not really apply to RPM builds
%pom_disable_module tycho-bundles-target tycho-bundles
%pom_xpath_remove "pom:target" tycho-bundles

# Disable maven-properties-plugin used by tests
%pom_remove_plugin org.sonatype.plugins:maven-properties-plugin tycho-extras/tycho-p2-extras-plugin
# Remove dep on maven tarball used by tests
%pom_remove_dep org.apache.maven:apache-maven tycho-extras/tycho-p2-extras-plugin

# we don't have org.apache.commons:commons-compress:jar:sources
%pom_xpath_remove "pom:dependency[pom:classifier='sources' and pom:artifactId='commons-compress']" tycho-p2/tycho-p2-director-plugin

# Don't build tests
for b in core.shared.tests p2.resolver.impl.test p2.resolver.shared.tests p2.maven.repository.tests p2.tools.tests test.utils ; do
  %pom_disable_module org.eclipse.tycho.$b tycho-bundles
done
%pom_disable_module org.fedoraproject.p2.tests fedoraproject-p2
%pom_disable_module tycho-testing-harness
%pom_remove_dep -r :::test

# Bootstrap Build
%if %{with bootstrap}

# Break circular dep between tycho-lib-detector and tycho-compiler-jdt for bootstrapping
%pom_remove_plugin :maven-compiler-plugin tycho-lib-detector

# Unpack a compatible version of Eclipse we can use to build against
tar -xf %{SOURCE10}
# Install OSGi bundles into local repo to override any incompatible system version
# that may be already installed
pushd bootstrap
for f in usr/lib/eclipse/plugins/org.eclipse.osgi.compatibility.state_*.jar \
         usr/lib/eclipse/plugins/org.eclipse.osgi.services_*.jar \
         usr/lib/eclipse/plugins/org.eclipse.osgi.util_*.jar \
         usr/lib/eclipse/plugins/org.eclipse.osgi_*.jar ; do
  xmvn -o install:install-file -Dfile=$f -Dpackaging=jar -DgroupId=org.eclipse.tycho -Dmaven.repo.local=$(pwd)/../.m2 \
    -DartifactId=$(echo $(basename $f) | cut -d_ -f1) -Dversion=$(echo "${f%.jar}" | cut -d_ -f2)
done
popd

# Perform the 'minimal' (bootstrap) build of Tycho
cp %{SOURCE3} %{SOURCE4} .
./tycho-bootstrap.sh %{version}

# Non-Bootstrap Build
%else

# Set some temporary build version so that the bootstrapped build has
# a different version from the nonbootstrapped. Otherwise there will
# be cyclic dependencies.

sysVer=`grep -C 1 "<artifactId>tycho</artifactId>" %{_mavenpomdir}/tycho/tycho.pom | grep "version" | sed 's/.*>\(.*\)<.*/\1/'`
mkdir boot
sed -e 's/ns[0-9]://g' %{_datadir}/maven-metadata/tycho.xml > boot/tycho-metadata.xml

# Copy Tycho POMs from system repo and set their versions to %%{version}-SNAPSHOT.
for pom in $(grep 'pom</path>' boot/tycho-metadata.xml | sed 's|.*>\(.*\)<.*|\1|'); do
    sed -e "s/>$sysVer/>%{version}-SNAPSHOT/g" -e "s/%{fp_p2_version}%{fp_p2_snap}/%{fp_p2_version}/" <$pom >boot/$(basename $pom)
done

# Update Maven lifecycle mappings for Tycho packaging types provided by tycho-maven-plugin.
cp -p $(build-classpath tycho/tycho-maven-plugin) boot/tycho-maven-plugin.jar
jar xf boot/tycho-maven-plugin.jar META-INF/plexus/components.xml
sed -i s/$sysVer/%{version}-SNAPSHOT/ META-INF/plexus/components.xml
jar uf boot/tycho-maven-plugin.jar META-INF/plexus/components.xml

# Create XMvn metadata for the new JARs and POMs by customizing system Tycho metadata.
sed -i -e 's/xmlns=".*"//' boot/tycho-metadata.xml
%pom_xpath_remove -f "metadata/artifacts/artifact[artifactId='org.eclipse.osgi']" boot/tycho-metadata.xml
%pom_xpath_remove -f "metadata/artifacts/artifact[artifactId='org.eclipse.osgi.util']" boot/tycho-metadata.xml
%pom_xpath_remove -f "metadata/artifacts/artifact[artifactId='org.eclipse.osgi.services']" boot/tycho-metadata.xml
%pom_xpath_remove -f "metadata/artifacts/artifact[artifactId='org.eclipse.osgi.compatibility.state']" boot/tycho-metadata.xml
sed -i '
  s|>/[^<]*/\([^/]*\.pom\)</path>|>'$PWD'/boot/\1</path>|
  s|>'$sysVer'</version>|>%{version}-SNAPSHOT</version><compatVersions><version>%{version}-SNAPSHOT</version></compatVersions>|
  s|>'%{fp_p2_version}%{fp_p2_snap}'</version>|>%{fp_p2_version}</version><compatVersions><version>%{fp_p2_version}</version></compatVersions>|
  s|%{_javadir}/tycho/tycho-maven-plugin.jar|'$PWD'/boot/tycho-maven-plugin.jar|
' boot/tycho-metadata.xml
%mvn_config resolverSettings/metadataRepositories/repository $PWD/boot/tycho-metadata.xml
%endif

# Avoid duplicate execution of clean when generating javadocs, see ebz#399756
%pom_add_plugin :maven-clean-plugin tycho-bundles/tycho-standalone-p2-director "
<executions>
  <execution>
    <id>default-clean-1</id>
    <phase>initialize</phase>
    <configuration>
      <skip>true</skip>
    </configuration>
  </execution>
</executions>"

# Add fp-p2 to main build
%pom_xpath_inject "pom:modules" "<module>fedoraproject-p2</module>"

%build
%mvn_build -f -- \
  -Dtycho-version=%{version}-SNAPSHOT -DtychoBootstrapVersion=%{version}-SNAPSHOT \
  -Dmaven.repo.local=$(pwd)/.m2 -Dfedora.p2.repos=$(pwd)/bootstrap

%mvn_artifact fedoraproject-p2/org.fedoraproject.p2/pom.xml

# Relying on xmvn p2 plugin being present would be a circular dep
# So install as if all artifacts are normal jar files
sed -i -e 's|type>eclipse.*<|type>jar<|' .xmvn-reactor

# Don't package target platform definition files
%mvn_package "::target::" __noinstall

%install
# Get debundling scripts
cp %{SOURCE3} %{SOURCE5} .

%if ! %{with bootstrap}
# Debundle p2 runtime
./tycho-debundle.sh $(pwd)/tycho-bundles/tycho-bundles-external \
  $(pwd)/tycho-bundles/tycho-bundles-external/target/tycho-bundles-external-manifest.txt

# Debundle standalone p2 director
./tycho-debundle.sh $(pwd)/tycho-bundles/tycho-standalone-p2-director
%endif

%if %{with bootstrap}
# Install our own copy of OSGi runtime when bootstrapping to avoid external dep on Eclipse
for b in org.eclipse.osgi \
         org.eclipse.osgi.util \
         org.eclipse.osgi.services \
         org.eclipse.osgi.compatibility.state ; do
  osgiJarPath=$(find .m2/org/eclipse/tycho/$b/*/ -name "*.jar")
  osgiPomPath=$(find .m2/org/eclipse/tycho/$b/*/ -name "*.pom")
  %mvn_artifact $osgiPomPath $osgiJarPath
done
%endif

%mvn_install

%if ! %{with bootstrap}
install -pm 644 tycho-bundles/tycho-bundles-external/target/tycho-bundles-external-manifest.txt %{buildroot}%{_javadir}/tycho
%add_maven_depmap org.eclipse.tycho:tycho-bundles-external:txt:manifest:%{version} tycho/tycho-bundles-external-manifest.txt
%endif

%if %{with bootstrap}
# Misc other bundles needed for bootstrapping
for bnd in \
  core.contenttype \
  core.expressions \
  core.filesystem \
  core.jobs \
  core.net \
  core.resources \
  core.runtime \
  equinox.app \
  equinox.common \
  equinox.concurrent \
  equinox.preferences \
  equinox.registry \
  equinox.security ; do
bndJarPath=$(find bootstrap -name "org.eclipse.${bnd}_*.jar")
install -m 644 -T $bndJarPath $RPM_BUILD_ROOT%{_javadir}/tycho/$bnd.jar
done
%endif

# For some reason fp-p2 is treated as a compat version, this prevents that
# TODO: figure out why
sed -i '/<resolvedVersion>/d' %{buildroot}%{_datadir}/maven-metadata/tycho.xml

# p2-install script
install -dm 755 %{buildroot}%{_javadir}-utils/
install -pm 755 %{SOURCE6} %{buildroot}%{_javadir}-utils/

# Symlink XMvn P2 plugin with all dependencies so that it can be loaded by XMvn
install -dm 755 %{buildroot}%{xmvn_libdir}/installer/
%if %{with bootstrap}
ln -s %{_javadir}/tycho/org.eclipse.osgi.jar %{buildroot}%{xmvn_libdir}/installer/
%else
ln -s %{_javadir}/eclipse/osgi.jar %{buildroot}%{xmvn_libdir}/installer/
%endif
ln -s %{_javadir}/tycho/xmvn-p2-installer-plugin.jar %{buildroot}%{xmvn_libdir}/installer/
ln -s %{_javadir}/tycho/org.fedoraproject.p2.jar %{buildroot}%{xmvn_libdir}/installer/

%files -f .mfiles
%{xmvn_libdir}/installer/*
%{_javadir}-utils/p2-install.sh
%if %{with bootstrap}
%{_javadir}/tycho/core.*.jar
%{_javadir}/tycho/equinox.*.jar
%endif
%doc README.md

%files javadoc -f .mfiles-javadoc


%changelog
* Tue Dec 08 2020 neoclust <neoclust> 1.7.0-2.mga8
+ Revision: 1654641
- Rebuild against new java stack

* Tue Dec 01 2020 tv <tv> 1.7.0-1.mga8
+ Revision: 1651291
- BR zip
- 1.7.0

* Sat Aug 15 2020 neoclust <neoclust> 1.5.0-1.mga8
+ Revision: 1614156
- New version in bootstrap mode
- New version 1.5.0
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Fri Jul 19 2019 daviddavid <daviddavid> 1.3.0-3.mga8
+ Revision: 1422697
- Debootstrap build
- Restrict to the same architectures as Eclipse itself

* Thu Jul 18 2019 daviddavid <daviddavid> 1.3.0-2.mga8
+ Revision: 1422551
- Bootstrap with new felix-scr

* Mon Mar 04 2019 daviddavid <daviddavid> 1.3.0-1.mga7
+ Revision: 1371343
- Update to latest upstream release 1.3.0
- Allow conditionally building Junit5 support
- Allow building against ASM 6

* Sat Dec 15 2018 neoclust <neoclust> 1.2.0-6.mga7
+ Revision: 1341358
- Rebuild in non bootstrap mode

* Fri Dec 14 2018 neoclust <neoclust> 1.2.0-5.mga7
+ Revision: 1341106
- Bootstrap mode improvements
+ daviddavid <daviddavid>
- non-bootstrap build

* Wed Dec 12 2018 daviddavid <daviddavid> 1.2.0-0.1.gitd9ce75d.mga7
+ Revision: 1340846
- new version: 1.2.0 (sync with fc29)
- bootstrap build

* Wed Sep 19 2018 umeabot <umeabot> 0.25.0-8.mga7
+ Revision: 1276893
- Mageia 7 Mass Rebuild

* Mon May 15 2017 neoclust <neoclust> 0.25.0-7.mga6
+ Revision: 1101832
- Sync with fc25

* Wed May 04 2016 neoclust <neoclust> 0.25.0-3.mga6
+ Revision: 1009190
- Disable bootstrap and remove sources
- Build with bootstrap disable

* Tue May 03 2016 neoclust <neoclust> 0.25.0-2.mga6
+ Revision: 1008906
- Rebuild with fixed ecj

* Mon May 02 2016 neoclust <neoclust> 0.25.0-1.mga6
+ Revision: 1008615
- Update to latest upstream release
- Full bootstrap mode due to incompatibility with Eclipse Mars

* Wed Mar 02 2016 neoclust <neoclust> 0.23.0-19.mga6
+ Revision: 983174
- Disable bootstrap
- Second rebuild of the java stack
- Rebuild tycho on bootstrap mode
- First rebuild of the java stack
- Try to build with tycho enable
- Try to bootstrap tycho
- sync package tycho with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Tue Dec 30 2014 pterjan <pterjan> 0.21.0-2.mga5
+ Revision: 807422
- Clean rebuild
- Sync with Fedora 21 (update to 0.21.0)
+ dmorgan <dmorgan>
- Bootstrap build and update to 0.20

* Wed Oct 15 2014 umeabot <umeabot> 0.19.0-3.mga5
+ Revision: 741950
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Sun Jun 15 2014 dmorgan <dmorgan> 0.19.0-1.mga5
+ Revision: 636477
- New version

* Wed Jan 08 2014 dmorgan <dmorgan> 0.18.1-10.mga4
+ Revision: 565546
- Fix BuildRequires

* Wed Dec 25 2013 dmorgan <dmorgan> 0.18.1-9.mga4
+ Revision: 560685
- Workaround %%clean issue

* Tue Oct 22 2013 umeabot <umeabot> 0.18.1-8.mga4
+ Revision: 546273
- Mageia 4 Mass Rebuild

* Mon Oct 07 2013 dmorgan <dmorgan> 0.18.1-7.mga4
+ Revision: 492425
- Do not use XMvn internals (rhbz #1015038)

* Thu Sep 26 2013 dmorgan <dmorgan> 0.18.1-6.mga4
+ Revision: 486592
- Rebuild against bootstrap rpm
- Add workaround for rhbz#1004310
- Improve artifact resolution using XMvn Resolver. (Bug 986900)
- Skip validateConsistentTychoVersion by default. (Bug 987271)
- New version 0.18.1
- Rebuild against new maven
- Mavenized versions org.eclipse.osgi and org.eclipse.jdt.core were
  provided by Eclipse, but since it depends on Tycho at build-time,
  we cannot depend upon it at runtime. Therefore we must provide these bundles.
- New version ( bootstrap enable)
- Disable bootstrap
- Use maven script to build

* Mon Jul 08 2013 dmorgan <dmorgan> 0.16.0-21.mga4
+ Revision: 451337
- Add support for more flexible OSGi bundle paths.

* Fri Jan 18 2013 dmorgan <dmorgan> 0.16.0-20.mga3
+ Revision: 389456
- Add support for more flexible OSGi bundle paths.
- Use OSGi Requires instead of package name.
- Expand Requires to include the Eclipse platform.
- Fix upstream Bug 361204.

* Mon Jan 14 2013 umeabot <umeabot> 0.16.0-19.mga3
+ Revision: 384933
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Dec 03 2012 dmorgan <dmorgan> 0.16.0-18.mga3
+ Revision: 326021
- Fix builrequires
- New snapshot
- Add apache-commons-codec/logging as buildrequire
- Add apache-commons-httpclient as buildrequire

* Fri Sep 14 2012 dmorgan <dmorgan> 0.16.0-7.df2c35.2.mga3
+ Revision: 293950
- Try to build in non bootstrap mode
- Rebuild after first bootstrap
- New version
- new version 0.14.1
- Revert to version 0.10
- Fix Tycho Surfire to run Eclipse test bundles.
- Implement automatic creation of a system p2 repository.
- Allow building SWT fragments (BZ #380934).
- Set BREE to be at least JavaSE-1.6 for Eclipse OSGi bundles
- Implement a custom resolver when running in local mode.
- Use upstream solution for BZ #372395 to fix the build.
- Add missing tycho-testing-harness to be packaged.
- Use %%{_eclipse_base} from eclipse-platform.

* Wed Jul 20 2011 dmorgan <dmorgan> 0.10.0-2.mga2
+ Revision: 126990
- Disable bootstrap

* Tue Jul 19 2011 dmorgan <dmorgan> 0.10.0-1.mga2
+ Revision: 126755
- imported package tycho


* Fri May 6 2011 Alexander Kurtakov <akurtako@redhat.com> 0.10.0-3
- Non-bootstrap build.

* Tue May  3 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0.10.0-2
- Add README and make build more silent

* Tue Mar 29 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0.10.0-1
- First bootstrapped version
